@@ -103,6 +103,7 @@ class Compiler:
             print(Style.DIM + cmd + Style.RESET_ALL)
 
             error = False
+            result = ''
             try:
                 result = subprocess.check_output(cmd, shell=True, stderr=subprocess.STDOUT)
             except subprocess.CalledProcessError as exec:
@@ -1045,21 +1046,21 @@ class Compiler_PRO2(Compiler):
 
     def compile(self):
         util.del_file(self.executable())
-        util.del_dir(self.name + ".dir")
+        util.del_dir(self.name + '.dir')
         os.mkdir(self.name + ".dir")
 
         try:
-            if util.file_exists(self.name + ".cc"):
-                util.system('cp ' + self.name + '.cc ' +
-                            self.name + '.dir/program.cc')
-            elif util.file_exists(name + ".hh"):
-                util.system('cp ' + self.name + '.hh ' +
-                            self.name + '.dir/program.hh')
+            if util.file_exists("solution.cc"):
+                util.system('cp solution.cc ' + self.name + '.dir/' + 'program.cc')
+            elif util.file_exists("solution.hh"):
+                util.system('cp solution.hh ' + self.name + '.dir/program.hh')
             else:
-                print("There is no " + self.name +
-                      ".cc nor " + self.name + ".hh")
+                print("There is no solution.cc nor solution.hh")
 
-            os.chdir(self.name + ".dir")
+            util.system('cp public/* ' + self.name + '.dir')
+            util.system('cp private/* ' + self.name + '.dir')
+
+            os.chdir(self.name + '.dir')
             self.execute_compiler('g++ ' + self.flags1() + ' *.cc -o ../' +
                                   self.executable())
         except CompilationTooLong:
@@ -1104,11 +1105,6 @@ class Compiler_MakePRO2(Compiler):
         return 'tar'
 
     def compile(self):
-        logging.info('compiling with MakePRO2')
-        logging.info('changing max_compilation_time')
-        global max_compilation_time
-        max_compilation_time = 30
-
         util.del_file(self.executable())
         util.del_dir(self.name + ".dir")
 
@@ -1125,8 +1121,7 @@ class Compiler_MakePRO2(Compiler):
                         self.name + '.dir')
             os.chdir(self.name + '.dir')
 
-            self.execute_compiler('make ' + self.name +
-                                  '.exe 1> make.log')
+            self.execute_compiler('make program.exe 1> make.log')
         except CompilationTooLong:
             print(Style.BRIGHT + Fore.RED + 'Compilation time exceeded!' + Style.RESET_ALL)
             os.chdir('..')
@@ -1134,8 +1129,8 @@ class Compiler_MakePRO2(Compiler):
 
         os.chdir('..')
 
-        if util.file_exists(self.name + '.dir/' + self.name + '.exe'):
-            util.copy_file(self.name + '.dir/' + self.name + '.exe', '.')
+        if util.file_exists(self.name + '.dir/program.exe'):
+            util.copy_file(self.name + '.dir/program.exe', './' + self.executable())
 
         util.del_dir(self.name + ".dir")
 
