@@ -378,7 +378,7 @@ def make_prints2(lang):
     tmp = util.tmp_dir()
     print(Style.DIM + ori + ' ' + lang + ' ' + tmp + ' ' + Style.RESET_ALL)
 
-    os.system("cp * %s/sty/* %s" %
+    os.system("cp * %s/sty/* %s 2>&1 | grep -v 'omitting directory'" %
               (os.path.dirname(os.path.abspath(__file__)), tmp))
     os.chdir(tmp)
 
